<?php
/**
 * Customizer settings: Other Pages > Custom Post Types
 *
 * @package Wengdo
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

foreach ( Wengdo_Customizer::instance()->get_all_page_settings_types() as $ps_type => $ps_data ) {
	$section = wengdo_array_value( $ps_data, 'section' );
	$option_prefix = $ps_type;

	// Abort if it's on detault pages which already have their own options.
	if ( in_array( $ps_type, array( 'post_archive', 'post_single', 'page_single', 'search_results', 'error_404' ) ) ) {
		continue;
	}

	// Abort if the post type has their own options.
	if ( ! apply_filters( 'wengdo/customizer/enable_auto_options_on_' . $ps_type, true ) ) {
		continue;
	}

	// Extract the post type slug from $ps_type.
	$post_type_slug = preg_replace( '/(_single|_archive)/', '', $ps_type );
	$post_type_obj = get_post_type_object( $post_type_slug );

	/**
	 * ====================================================
	 * Content Header
	 * ====================================================
	 */

	// Heading: Content Header
	$wp_customize->add_control( new Wengdo_Customize_Control_Heading( $wp_customize, 'heading_' . $ps_type . '_content_header', array(
		'section'     => $section,
		'settings'    => array(),
		'label'       => esc_html__( 'Content Header', 'wengdo' ),
		'priority'    => 20,
	) ) );

	// Elements
	$elements = array(
		'title'      => esc_html__( 'Title', 'wengdo' ),
		'breadcrumb' => esc_html__( 'Breadcrumb', 'wengdo' ),
	);
	// Archive elements.
	if ( false !== strpos( $ps_type, '_archive' ) ) {
		$elements['archive-description'] = esc_html__( 'Taxonomy Description', 'wengdo' );
	}
	$subkey = 'content_header';
	$key = $option_prefix . '_' . $subkey;
	$wp_customize->add_setting( $key, array(
		'default'     => wengdo_array_value( $defaults, $key ),
		'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'multiselect' ),
	) );
	$wp_customize->add_control( new Wengdo_Customize_Control_Sortable( $wp_customize, $key, array(
		'section'     => $section,
		// 'label'       => esc_html__( 'Elements', 'wengdo' ),
		'choices'     => apply_filters( 'wengdo/dataset/' . $ps_type . '_content_header_elements', $elements ),
		'priority'    => 20,
	) ) );

	// Alignment
	$subkey = 'content_header_alignment';
	$key = $option_prefix . '_' . $subkey;
	$wp_customize->add_setting( $key, array(
		'default'     => wengdo_array_value( $defaults, $key ),
		'transport'   => 'postMessage',
		'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
	) );
	$wp_customize->add_control( new Wengdo_Customize_Control_RadioImage( $wp_customize, $key, array(
		'section'     => $section,
		// 'label'       => esc_html__( 'Alignment', 'wengdo' ),
		'choices'     => array(
			'left'   => array(
				'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'right' : 'left' ) . '"></span>',
			),
			'center' => array(
				'label' => '<span class="dashicons dashicons-editor-aligncenter"></span>',
			),
			'right'  => array(
				'label' => '<span class="dashicons dashicons-editor-align' . ( is_rtl() ? 'left' : 'right' ) . '"></span>',
			),
		),
		'priority'    => 20,
	) ) );

	// Title text format on archive pages
	if ( false !== strpos( $ps_type, '_archive' ) ) {

		// Title text format on post type archive pages
		$subkey = 'title_text';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'text' ),
		) );
		$wp_customize->add_control( $key, array(
			'section'     => $section,
			/* translators: %s: post type's plural name. */
			'label'       => sprintf( esc_html__( '%s page title', 'wengdo' ), $post_type_obj->labels->name ),
			'description' => esc_html__( 'Available tags: {{post_type}}.', 'wengdo' ),
			'input_attrs' => array(
				'placeholder' => '{{post_type}}',
			),
			'priority'    => 20,
		) );

		// Title text format on taxonomy archive pages
		$subkey = 'tax_title_text';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'text' ),
		) );
		$wp_customize->add_control( $key, array(
			'section'     => $section,
			'label'       => esc_html__( 'Taxonomy archive page title', 'wengdo' ),
			'description' => esc_html__( 'Available tags: {{taxonomy}}, {{term}}.', 'wengdo' ),
			'input_attrs' => array(
				'placeholder' => '{{taxonomy}}: {{term}}',
			),
			'priority'    => 20,
		) );
	}

	/**
	 * ====================================================
	 * Featured Image
	 * ====================================================
	 */

	if ( strpos( $ps_type, '_single' ) && post_type_supports( $post_type_slug, 'thumbnail' ) ) {
		// Heading: Featured Image
		$wp_customize->add_control( new Wengdo_Customize_Control_Heading( $wp_customize, 'heading_' . $ps_type . '_content_thumbnail', array(
			'section'     => $section,
			'settings'    => array(),
			'label'       => esc_html__( 'Featured Image', 'wengdo' ),
			'priority'    => 30,
		) ) );
	
		// Display
		$subkey = 'content_thumbnail_position';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
		) );
		$wp_customize->add_control( $key, array(
			'type'        => 'select',
			'section'     => $section,
			'label'       => esc_html__( 'Display', 'wengdo' ),
			'choices'     => array(
				''       => esc_html__( 'Disabled', 'wengdo' ),
				'before' => esc_html__( 'Before Content Header', 'wengdo' ),
				'after'  => esc_html__( 'After Content Header', 'wengdo' ),
			),
			'priority'    => 30,
		) );
	
		// Wide alignment
		$subkey = 'content_thumbnail_wide';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'toggle' ),
		) );
		$wp_customize->add_control( new Wengdo_Customize_Control_Toggle( $wp_customize, $key, array(
			'section'     => $section,
			'label'       => esc_html__( 'Wide alignment on Narrow container', 'wengdo' ),
			'priority'    => 30,
		) ) );
	}
}