<?php
/**
 * Customizer settings: Page Settings
 *
 * @package Wengdo
 **/

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

foreach ( Wengdo_Customizer::instance()->get_all_page_settings_types() as $ps_type => $ps_data ) {
	$section = wengdo_array_value( $ps_data, 'section' );
	$option_prefix = $ps_type;

	// Extract the post type slug from $ps_type.
	$post_type_slug = preg_replace( '/(_single|_archive)/', '', $ps_type );
	$post_type_obj = get_post_type_object( $post_type_slug );

	/**
	 * ====================================================
	 * Individual Page Settings
	 * ====================================================
	 */

	// Heading: Individual Page Settings
	$title = esc_html__( 'Individual Page Settings', 'wengdo' );
	if ( false !== strpos( $ps_type, '_single' ) ) {
		$title .= ' <span class="wengdo-global-default-badge wengdo-tooltip" tabindex="0" data-tooltip="' . sprintf( esc_attr__( 'You can override these options on each individual %s.', 'wengdo' ), $post_type_obj->labels->singular_name ) . '"><span class="dashicons dashicons-admin-site-alt3"></span></span>';
	}
	$wp_customize->add_control( new Wengdo_Customize_Control_Heading( $wp_customize, 'heading_' . $ps_type . '_page_settings', array(
		'section'     => $section,
		'settings'    => array(),
		'label'       => $title,
		'priority'    => 100,
	) ) );

	if ( 'error_404' !== $ps_type ) {

		// Content container
		$subkey = 'content_container';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
		) );
		$wp_customize->add_control( $key, array(
			'type'        => 'select',
			'section'     => $section,
			'label'       => esc_html__( 'Content container', 'wengdo' ),
			'choices'     => array(
				''           => esc_html__( '-- Global --', 'wengdo' ),
				'narrow'     => esc_html__( 'Narrow', 'wengdo' ),
				'default'    => esc_html__( 'Normal', 'wengdo' ),
				'full-width' => esc_html__( 'Full width', 'wengdo' ),
			),
			'priority'    => 100,
		) );

		// Info
		$wp_customize->add_control( new Wengdo_Customize_Control_Blank( $wp_customize, 'notice_' . $option_prefix . '_sidebar_on_narrow_layout', array(
			'section'     => $section,
			'settings'    => array(),
			'description' => '<div class="notice notice-info notice-alt inline"><p>' . esc_html__( 'Narrow content layout doesn\'t support Sidebar.', 'wengdo' ) . '</p></div>',
			'priority'    => 100,
		) ) );

		// Sidebar
		$subkey = 'content_layout';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
		) );
		$wp_customize->add_control( $key, array(
			'type'        => 'select',
			'section'     => $section,
			'label'       => esc_html__( 'Sidebar', 'wengdo' ),
			'choices'     => array(
				''              => esc_html__( '-- Global --', 'wengdo' ),
				'wide'          => esc_html__( 'None', 'wengdo' ),
				'right-sidebar' => is_rtl() ? esc_html__( 'Left', 'wengdo' ) : esc_html__( 'Right', 'wengdo' ),
				'left-sidebar'  => is_rtl() ? esc_html__( 'Right', 'wengdo' ) : esc_html__( 'Left', 'wengdo' ),
			),
			'priority'    => 110,
		) );
		
		// ------
		$wp_customize->add_control( new Wengdo_Customize_Control_HR( $wp_customize, 'hr_' . $ps_type . '_hero', array(
			'section'     => $section,
			'settings'    => array(),
			'priority'    => 120,
		) ) );

		// Hero section
		$subkey = 'hero';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
		) );
		$wp_customize->add_control( $key, array(
			'type'        => 'select',
			'section'     => $section,
			'label'       => esc_html__( 'Hero section', 'wengdo' ),
			'choices'     => array(
				''  => esc_html__( '-- Global --', 'wengdo' ),
				'1' => esc_html__( '&#x2714; Enabled', 'wengdo' ),
				'0' => esc_html__( '&#x2718; Disabled', 'wengdo' ),
			),
			'priority'    => 120,
		) );

		// Container
		$subkey = 'hero_container';
		$key = $option_prefix . '_' . $subkey;
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
		) );
		$wp_customize->add_control( $key, array(
			'type'        => 'select',
			'section'     => $section,
			'label'       => esc_html__( 'Container', 'wengdo' ),
			'choices'     => array(
				''           => esc_html__( '-- Global --', 'wengdo' ),
				'default'    => esc_html__( 'Normal', 'wengdo' ),
				'full-width' => esc_html__( 'Full width', 'wengdo' ),
				'narrow'     => esc_html__( 'Narrow', 'wengdo' ),
			),
			'priority'    => 120,
		) );

		// Background image
		$subkey = 'hero_bg';
		$key = $option_prefix . '_' . $subkey;
		$choices = array(
			''          => esc_html__( '-- Global --', 'wengdo' ),
			'thumbnail' => esc_html__( 'Feat. Image', 'wengdo' ),
			'custom'    => esc_html__( 'Custom Image', 'wengdo' ),
		);
		if ( false === strpos( $ps_type, '_single' ) || ! post_type_supports( $post_type_slug, 'thumbnail' ) ) {
			unset( $choices['thumbnail'] );
		}
		$wp_customize->add_setting( $key, array(
			'default'     => wengdo_array_value( $defaults, $key ),
			'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
		) );
		$wp_customize->add_control( $key, array(
			'type'        => 'select',
			'section'     => $section,
			'label'       => esc_html__( 'Background image', 'wengdo' ),
			'choices'     => $choices,
			'priority'    => 120,
		) );

			// Custom background image
			$subkey = 'hero_bg_image';
			$key = $option_prefix . '_' . $subkey;
			$wp_customize->add_setting( $key, array(
				'default'     => wengdo_array_value( $defaults, $key ),
				'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'image' ),
			) );
			$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $key, array(
				'section'     => $section,
				// 'label'       => esc_html__( 'Custom background image', 'wengdo' ),
				'priority'    => 120,
			) ) );
		
		// ------
		$wp_customize->add_control( new Wengdo_Customize_Control_HR( $wp_customize, 'hr_' . $ps_type . '_header', array(
			'section'     => $section,
			'settings'    => array(),
			'priority'    => 130,
		) ) );
	}

	// Desktop Header
	$subkey = 'disable_header';
	$key = $option_prefix . '_' . $subkey;
	$wp_customize->add_setting( $key, array(
		'default'     => wengdo_array_value( $defaults, $key ),
		'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
	) );
	$wp_customize->add_control( $key, array(
		'type'        => 'select',
		'section'     => $section,
		'label'       => esc_html__( 'Desktop Header', 'wengdo' ),
		'choices'     => array(
			''  => esc_html__( '&#x2714; Visible', 'wengdo' ),
			'1' => esc_html__( '&#x2718; Hidden', 'wengdo' ),
		),
		'priority'    => 130,
	) );

	// Mobile Header
	$subkey = 'disable_mobile_header';
	$key = $option_prefix . '_' . $subkey;
	$wp_customize->add_setting( $key, array(
		'default'     => wengdo_array_value( $defaults, $key ),
		'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
	) );
	$wp_customize->add_control( $key, array(
		'type'        => 'select',
		'section'     => $section,
		'label'       => esc_html__( 'Mobile Header', 'wengdo' ),
		'choices'     => array(
			''  => esc_html__( '&#x2714; Visible', 'wengdo' ),
			'1' => esc_html__( '&#x2718; Hidden', 'wengdo' ),
		),
		'priority'    => 140,
	) );

	// ------
	$wp_customize->add_control( new Wengdo_Customize_Control_HR( $wp_customize, 'hr_' . $ps_type . '_footer', array(
		'section'     => $section,
		'settings'    => array(),
		'priority'    => 150,
	) ) );

	// Footer widgets
	$subkey = 'disable_footer_widgets';
	$key = $option_prefix . '_' . $subkey;
	$wp_customize->add_setting( $key, array(
		'default'     => wengdo_array_value( $defaults, $key ),
		'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
	) );
	$wp_customize->add_control( $key, array(
		'type'        => 'select',
		'section'     => $section,
		'label'       => esc_html__( 'Footer widgets', 'wengdo' ),
		'choices'     => array(
			''  => esc_html__( '&#x2714; Visible', 'wengdo' ),
			'1' => esc_html__( '&#x2718; Hidden', 'wengdo' ),
		),
		'priority'    => 150,
	) );

	// Footer bottom
	$subkey = 'disable_footer_bottom';
	$key = $option_prefix . '_' . $subkey;
	$wp_customize->add_setting( $key, array(
		'default'     => wengdo_array_value( $defaults, $key ),
		'sanitize_callback' => array( 'Wengdo_Customizer_Sanitization', 'select' ),
	) );
	$wp_customize->add_control( $key, array(
		'type'        => 'select',
		'section'     => $section,
		'label'       => esc_html__( 'Footer bottom', 'wengdo' ),
		'choices'     => array(
			''  => esc_html__( '&#x2714; Visible', 'wengdo' ),
			'1' => esc_html__( '&#x2718; Hidden', 'wengdo' ),
		),
		'priority'    => 150,
	) );
}