<?php
/**
 * Wengdo setup
 *
 * @package wengdo
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\Controls_Manager;
add_filter('wengdo_add_contents_fields', 'wengdo_theme_contents_fields');

function wengdo_theme_contents_fields() {

		$contents_type_fields = [
			'label' => sprintf( esc_html__( '%1$s Add Content', 'wengdo' ), ucfirst(get_template() ) ),
			'controls' => [
				'posts_per_page' => [
					'label' => esc_html__( 'Number of posts displayed', 'wengdo' ),
					'type' => Controls_Manager::TEXT,
					'default' => '5',
					'description' => esc_html__( 'The number of posts you want to show.', 'wengdo' ),
					'label_block' => true,
				],
				'post_type' => [
					'label' => esc_html__( 'Content Type', 'wengdo' ),
					'type' => Controls_Manager::SELECT,
					'description' =>esc_html__( 'Not all content type will be listed here. We list only those we have template in this theme for.', 'wengdo' ),
					'default'  => 'post',
					'options'  => [
						 'post'            => esc_html__(' Posts', 'wengdo'),
						 'product'         => esc_html__(' Products', 'wengdo'),
					],
				],

				'orderby' => [
					'label' => esc_html__( 'Order by', 'wengdo' ),
					'type' => Controls_Manager::SELECT,
					'description' =>esc_html__( 'Order this content by...', 'wengdo' ),
					'default'  => 'date',
					'options'  => [
						  'date'            =>      esc_html__(' Date', 'wengdo'),
						  'ID'              =>      esc_html__(' Post ID', 'wengdo'),
						  'author'          =>      esc_html__(' Author', 'wengdo'),
						  'title'           =>      esc_html__(' Title', 'wengdo'),
						  'name'            =>      esc_html__(' Post name (post slug)', 'wengdo'),
						  'modified'        =>      esc_html__(' Last modified date', 'wengdo'),
						  'rand'            =>      esc_html__(' Random order', 'wengdo'),
						  'comment_count'   =>      esc_html__(' Number of comments', 'wengdo'),
					],
				],

				'order' => [
					'label' => esc_html__( 'Order', 'wengdo' ),
					'type' => Controls_Manager::SELECT,
					'default'  => 'DESC',
					'options'  => [
						  'DESC'            =>      esc_html__(' DESC', 'wengdo'),
						  'ASC'             =>      esc_html__(' ASC', 'wengdo'),
					],
				],

				'tt_id' => [
					'label' => esc_html__( 'Post Ids', 'wengdo' ),
					'type' => Controls_Manager::TEXT,
					'default' => '',
					'description' => esc_html__( 'If you want to display particular posts, enter their IDs comma separated. eg 101,202,300. Recommended: Leave blank', 'wengdo' ),
					'label_block' => true,
				],

				'tt_template' => [
					'label' => esc_html__( 'Display Template', 'wengdo' ),
					'type' => Controls_Manager::SELECT,
					'description' => esc_html__( 'There are prebuilt templates to display certain content in this theme. You are requested not to edit this.', 'wengdo' ),
					'default'  => 'default',
					'options'  => [
						'default'           =>  esc_html__(' Default', 'wengdo'),
						'blog-grid'         =>  esc_html__(' Blog Grid', 'wengdo'),
						//'isotop-tmpl'       =>  esc_html__(' Isotop', 'wengdo'),
					],
				],

				'enable_filter' => [
					'label' => esc_html__( 'Enable Filter ?', 'wengdo' ),
					'type' => Controls_Manager::SWITCHER,
					'description' => esc_html__( 'If set to yes, the gallery is filterable by the category. Not applicable to all cases. Page refresh needed to apply changes.', 'wengdo' ),
					'default' => 'true',
					'prefix_class' => 'elementor-',
					'label_on' => 'Yes',
					'label_off' => 'No',
					'return_value' => 'true',
					'condition' => [
						'tt_template' => [ 'isotop-tmpl', 'gallery-page' ],
					],
				],

				'enable_all_btn' => [
					'label' => esc_html__( 'Enable ALL button ?', 'wengdo' ),
					'type' => Controls_Manager::SWITCHER,
					'description' => esc_html__( 'If set to yes, All link appears first that displays all items. Not applicable to all cases. Page refresh needed to apply changes.', 'wengdo' ),
					'default' => 'true',
					'prefix_class' => 'elementor-',
					'label_on' => 'Yes',
					'label_off' => 'No',
					'return_value' => 'true',
					'condition' => [
						'tt_template' => [ 'isotop-tmpl', 'gallery-page' ],
					],
				],
				/* The param name should not be changed. */
				/* spl_title */
				'spl_field1' => [
					'label' => esc_html__( 'Title (Optional)', 'wengdo' ),
					'type' => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter the title for the entire block. Leave blank to disable.', 'wengdo' ),
					'label_block' => true,
					'condition' => [
						'tt_template' => [ 'default' ],
					],
				],
				/* spl_button */
				'spl_field2' => [
					"label" => esc_html__("Button Label (Optional)", 'wengdo'),
					'type' => Controls_Manager::TEXT,
					'description' => esc_html__( 'Leave blank to disable button.', 'wengdo' ),
					'label_block' => true,
					'condition' => [
						'tt_template' => [ 'blog3' ],
					],
				],
				/* spl_target */
				'spl_field3' => [
					"label" => esc_html__("Open links in:",'wengdo'),
					'type' => Controls_Manager::SELECT,
					'label_block' => true,
					'options'  => [
						'_self'           =>  esc_html__(' Same window', 'wengdo'),
						'_blank'   =>  esc_html__(' New window', 'wengdo'),
					],
					'condition' => [
						'tt_template' => [ 'blog3' ],
					],
				],
				/* spl_link */
				'spl_field4' => [
					"label" => esc_html__("Button Link:",'wengdo'),
					'type' => Controls_Manager::TEXT,
					'description' => esc_html__( 'The link for the above button.', 'wengdo' ),
					'label_block' => true,
					'condition' => [
						'tt_template' => [ 'blog3' ],
					],
				],

				'spl_field5' => [
					'label' => esc_html__( 'Subtitle (Optional)', 'wengdo' ),
					'type' => Controls_Manager::TEXT,
					'description' => esc_html__( 'Enter the subtitle for the entire block. Leave blank to disable.', 'wengdo' ),
					'label_block' => true,
					'condition' => [
						'tt_template' => [ 'default' ],
					],
				],

				'spl_field6' => [
					'label' => esc_html__( 'Description (Optional)', 'wengdo' ),
					'type' => Controls_Manager::TEXTAREA,
					'description' => esc_html__( 'Enter the description for the entire block. Leave blank to disable. Plain text only, new line or html will not work.', 'wengdo' ),
					'label_block' => true,
					'condition' => [
						'tt_template' => [ 'default' ],
					],
				],

			],
		];

		return $contents_type_fields;

}
