<?php
/**
 * Header shopping cart dropdown template.
 *
 * Passed variables:
 *
 * @type string $element Header element.
 *
 * @package Wengdo
 */

// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'WooCommerce' ) ) {
	return;
}

$cart = WC()->cart;

if ( empty( $cart ) ) {
	return;
}

// Dropdown
ob_start();
the_widget( 'WC_Widget_Cart', array(
	'title'         => '',
	'hide_if_empty' => false,
) );
$dropdown_html = ob_get_clean();
if ( ! empty( $dropdown_html ) ) {
	$is_dropdown = true;
} else {
	$is_dropdown = false;
}

// Amount
$amount_position = wengdo_get_theme_mod( 'header_cart_amount', '' );
$amount_html = '';
if ( '' !== $amount_position ) {
	$classes = array();
	$hide_devices = array_diff( array( 'desktop', 'tablet', 'mobile' ), wengdo_get_theme_mod( 'header_cart_amount_visibility' ) );
	foreach( $hide_devices as $device ) {
		$classes[] = esc_attr( 'wengdo-hide-on-' . $device );
	}

	ob_start();
	?>
	<span class="cart-amount <?php echo esc_attr( implode( ' ', $classes ) ); ?>"><?php echo wp_kses_post($cart->get_cart_total()); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
	<?php
	$amount_html = ob_get_clean();
}
?>
<div class="<?php echo esc_attr( 'wengdo-header-' . $element ); ?> wengdo-header-cart menu <?php echo esc_html($is_dropdown) ? esc_attr( 'wengdo-toggle-menu' ) : ''; ?>">
	<div class="menu-item">
		<?php if ( $is_dropdown ) : ?>
		<button class="cart-link wengdo-menu-item-link wengdo-sub-menu-toggle wengdo-toggle" aria-expanded="false">
			<?php else: ?>
			<a href="<?php echo esc_url( wc_get_cart_url() ); ?>" class="cart-link wengdo-menu-item-link">
				<?php endif; ?>

				<span class="screen-reader-text"><?php esc_html_e( 'Shopping Cart', 'wengdo' ); ?></span>

				<?php if ( 'before' === $amount_position ) {
					echo do_shortcode($amount_html); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				} ?>

				<span class="cart-icon">
					<?php wengdo_icon( 'cart', array( 'class' => 'wengdo-menu-icon' ) ); ?>
				</span>

				<span class="cart-count" data-count="<?php echo esc_attr( $cart->get_cart_contents_count() ); ?>"><?php echo do_shortcode($cart->get_cart_contents_count()); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>

				<?php if ( 'after' === $amount_position ) {
					echo do_shortcode($amount_html); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				} ?>

				<?php if ( $is_dropdown ) : ?>
		</button>
	<?php else: ?>
		</a>
	<?php endif; ?>

		<?php if ( $is_dropdown ) : ?>
			<div class="sub-menu"><?php echo do_shortcode($dropdown_html); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></div>
		<?php endif; ?>
	</div>
</div>